summaryrefslogtreecommitdiffstats
path: root/src/corelib/tools/qhash.cpp
diff options
context:
space:
mode:
authorMartin Smith <martin.smith@qt.io>2018-01-03 14:44:54 +0100
committerMartin Smith <martin.smith@qt.io>2018-01-04 12:49:23 +0000
commit8c322c0b2c80954f6877f0f0a1e799c1e8516ba6 (patch)
tree436158b793714ee0f8c8652c8768d57aeb892cc7 /src/corelib/tools/qhash.cpp
parent03b226135f86839e4c54db8bf1b9dbab0eb24efa (diff)
doc: Correct remaining qdoc warnings in qhash.cpp
Added template clause to several qHash() functions and created a \typedef comment for QHash::const_key_value_iterator. Change-Id: Id56191f69bf9f36e606101e46bf1dfa528d88e09 Reviewed-by: Topi Reiniƶ <topi.reinio@qt.io>
Diffstat (limited to 'src/corelib/tools/qhash.cpp')
-rw-r--r--src/corelib/tools/qhash.cpp22
1 files changed, 17 insertions, 5 deletions
diff --git a/src/corelib/tools/qhash.cpp b/src/corelib/tools/qhash.cpp
index e72b3e1eb5..5f0b131342 100644
--- a/src/corelib/tools/qhash.cpp
+++ b/src/corelib/tools/qhash.cpp
@@ -736,7 +736,7 @@ void QHashData::checkSanity()
#endif
/*!
- \fn uint qHash(const QPair<T1, T2> &key, uint seed = 0)
+ \fn template <typename T1, typename T2> uint qHash(const QPair<T1, T2> &key, uint seed = 0)
\since 5.0
\relates QHash
@@ -746,7 +746,7 @@ void QHashData::checkSanity()
*/
/*!
- \fn uint qHash(const std::pair<T1, T2> &key, uint seed = 0)
+ \fn template <typename T1, typename T2> uint qHash(const std::pair<T1, T2> &key, uint seed = 0)
\since 5.7
\relates QHash
@@ -762,7 +762,7 @@ void QHashData::checkSanity()
constraints, we cannot change the QPair algorithm to match the std::pair one before Qt 6.
*/
/*! \fn uint qHashRange(InputIterator first, InputIterator last, uint seed = 0)
\relates QHash
\since 5.5
@@ -801,7 +801,7 @@ void QHashData::checkSanity()
\sa qHashBits(), qHashRangeCommutative()
*/
/*! \fn uint qHashRangeCommutative(InputIterator first, InputIterator last, uint seed = 0)
\relates QHash
\since 5.5
@@ -1024,7 +1024,7 @@ uint qHash(long double key, uint seed) Q_DECL_NOTHROW
Returns the hash value for the \a key, using \a seed to seed the calculation.
*/
/*! \fn uint qHash(const T *key, uint seed = 0)
\relates QHash
\since 5.0
@@ -2478,6 +2478,18 @@ uint qHash(long double key, uint seed) Q_DECL_NOTHROW
Returns the underlying const_iterator this key_iterator is based on.
*/
+/*! \typedef QHash::const_key_value_iterator
+ \inmodule QtCore
+ \since 5.10
+ \brief The QMap::const_key_value_iterator typedef provides an STL-style const iterator for QHash and QMultiHash.
+
+ QHash::const_key_value_iterator is essentially the same as QHash::const_iterator
+ with the difference that operator*() returns a key/value pair instead of a
+ value.
+
+ \sa QKeyValueIterator
+*/
+
/*! \typedef QHash::key_value_iterator
\inmodule QtCore
\since 5.10
@@ -762,7 +762,7 @@ void QHashData::checkSanity()
constraints, we cannot change the QPair algorithm to match the std::pair one before Qt 6.
*/
-/*! \fn uint qHashRange(InputIterator first, InputIterator last, uint seed = 0)
+/*! \fn template <typename InputIterator> uint qHashRange(InputIterator first, InputIterator last, uint seed = 0)
\relates QHash
\since 5.5
@@ -801,7 +801,7 @@ void QHashData::checkSanity()
\sa qHashBits(), qHashRangeCommutative()
*/
-/*! \fn uint qHashRangeCommutative(InputIterator first, InputIterator last, uint seed = 0)
+/*! \fn template <typename InputIterator> uint qHashRangeCommutative(InputIterator first, InputIterator last, uint seed = 0)
\relates QHash
\since 5.5
@@ -1024,7 +1024,7 @@ uint qHash(long double key, uint seed) Q_DECL_NOTHROW
Returns the hash value for the \a key, using \a seed to seed the calculation.
*/
-/*! \fn uint qHash(const T *key, uint seed = 0)
+/*! \fn template <class T> uint qHash(const T *key, uint seed = 0)
\relates QHash
\since 5.0